# PODY
[![PyPI](https://img.shields.io/pypi/v/pody)](https://pypi.org/project/pody/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/pody)](https://pypi.org/project/pody/)
[![intro-en](https://img.shields.io/badge/Introduction-Click_to_view-8A2BE2?style=social)](https://menxli.github.io/pody)

A simple pod manager.   
It allows client user to manage pod with limited access to the host system.

More information can be found in the [documentation](https://menxli.github.io/pody/index.html).